Tournament Portsmouth, England December 8th 1999 11 players William Lee https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/gzynroETMFU/discussion Malkavian Derangement Crypt (12 cards, min=14, max=36, avg=6.33) ------------------------------------------ 2x Vasantasena 9 AUS DEM OBF dom pot Malkavian antitribu:2 2x Korah 7 AUS DEM OBF ani priscus Malkavian antitribu:2 1x Hannibal 10 AUS DEM OBF cel dom cardinal Malkavian antitribu:2 1x Virgil 8 AUS DEM OBF cel bishop Malkavian antitribu:2 1x Artemis 6 DEM OBF aus cel for Malkavian antitribu:2 1x Quira, The Bitch Queen 6 AUS OBF obt tha Malkavian antitribu:2 1x Muriel Foucade 5 DEM aus Malkavian antitribu:2 1x Claven 4 aus dem obf Malkavian antitribu:2 1x Yorik 3 dem obf Malkavian antitribu:2 1x Boy Toy 2 dem Malkavian antitribu:2 Library (77 cards) Master (11) 1x Blood Doll 2x Dementation 1x Elysium: The Arboretum 1x Golconda: Inner Peace 2x Malkavian Derangement: Paranoia 2x Minion Tap 1x Obfuscate 1x Sudden Reversal Action (13) 1x Blessing of Chaos 8x Derange 3x Kindred Spirits 1x Revelations Ally (1) 1x Dauntain Black Magician Equipment (6) 1x Deer Rifle 1x Enchanted Marionette 1x Ivory Bow 3x Leather Jacket Political Action (7) 1x Banishment 2x Cardinal Benediction 1x Crusade: Miami 1x Disputed Territory 2x Sacrifice Retainer (1) 1x Mr. Winthrop Action Modifier (16) 4x Cloak the Gathering 2x Confusion 3x Eyes of Chaos 1x Forgotten Labyrinth 4x Lost in Crowds 1x Mind Tricks 1x Walk through Arcadia Action Modifier/Combat (2) 2x Swallowed by the Night Reaction (15) 2x Cardinal Sin: Insubordination 2x Forced Awakening 2x Precognition 3x Spirit's Touch 3x Telepathic Misdirection 3x Wake with Evening's Freshness Combat (5) 2x Coma 3x Quick Exit